
======
Others
======

News
====

* `盘点 | 过去一年拿到融资的脑机接口玩家 <http://www.sohu.com/a/133576854_652096>`_
* `这些公司和马斯克一样，想把大脑和机器连接起来 <https://www.leiphone.com/news/201704/xgWWiYDG8pjWgy0Z.html>`_
* `哈佛大学华人博士，创2家顶尖脑机接口公司，将科幻变为现实 <http://wemedia.ifeng.com/13094117/wemedia.shtml>`_
* `“人脑直连电脑”或在十年内实现，可穿戴设备将破译脑电波 <http://www.thepaper.cn/newsDetail_forward_1670498>`_
* `从霍金到阿凡达：脑机接口植入让你的思想“读”出来 <http://tech.sina.com.cn/d/i/2016-08-17/doc-ifxuxnah3722629.shtml>`_
* `如何看待伊隆·马斯克创办的脑机接口公司 Neuralink？ <https://www.zhihu.com/question/57713553>`_
* `脑机接口新突破：首次实现双向通信 <http://www.jiqizhixin.com/article/2345>`_
* `Brain-machine interfaces: Bidirectional communication at last <https://www.sciencedaily.com/releases/2017/02/170222131442.htm>`_

Websites
========

* `脑机世界 BCI <http://www.bciworld.cn/>`_


Books
=====

* `脑机穿越 <https://book.douban.com/subject/26318103/>`_


Papers
======

* [17.01] `Rapid Integration of Artificial Sensory Feedback during Operant Conditioning of Motor Cortex Neurons <http://www.sciencedirect.com/science/article/pii/S0896627317300478>`_
